cd $SRC_DIR

cmake -G "NMake Makefiles" %RECIPE_DIR%\..\..\..\ -DBUILD_PYTHON_WRAPPER=ON -DCONDA_BUILD=ON -DCMAKE_BUILD_TYPE="Release" -DLIBRARY_LIB=%LIBRARY_LIB% -DLIBRARY_INC=%LIBRARY_INC% -DCMAKE_INSTALL_PREFIX=%LIBRARY_PREFIX%


nmake install

if errorlevel 1 exit 1